@@ -81,7 +81,7 @@ def proc_background(
 def proc_slider(
         image_dir: str,
         out_path: str = None,
-        white_value: int = 255,
+        white_value_max: int = 255,  # 灰度判断为白色的最大值
         alpha_white_max: int = None  # 透明度通道为白色的最大值
 ):
     """
@@ -90,7 +90,7 @@ def proc_slider(
     将灰度超过一定值的像素保留，其他像素全部转换为黑色，方便识别
     :param image_dir:
     :param out_path:
-    :param white_value:
+    :param white_value_max: 灰度判断为白色的最大值，例如：255
     :param alpha_white_max: 透明度通道为白色的最大值，例如：15
     :return:
     """
@@ -107,28 +107,27 @@ def proc_slider(
         pass
     proc_file_dir = "%s%s%s" % (out_path, path_separator, image_proc_file_name)
 
-    if alpha_white_max is not None:
-        image = cv2.imread(image_dir, cv2.IMREAD_UNCHANGED)  # 4个通道
-    else:
-        image = cv2.imread(image_dir)  # 灰度
-        image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)  # 灰度
-    height = image.shape[0]  # 高
-    weight = image.shape[1]  # 宽
+    image_unchanged = cv2.imread(image_dir, cv2.IMREAD_UNCHANGED)  # 4个通道
+    image_gray = cv2.cvtColor(image_unchanged, cv2.COLOR_BGR2GRAY)  # 转换为灰度图
+
+    height = image_gray.shape[0]  # 高
+    weight = image_gray.shape[1]  # 宽
 
     for each_height in range(height):
         for each_weight in range(weight):
+            # 遍历图像的每个像素
             if alpha_white_max is not None:
-                if image[each_height, each_weight][3] <= 15:
-                    image[each_height, each_weight] = 255  # 判定为最白区域的，直接改为白色
+                if image_unchanged[each_height, each_weight][3] <= alpha_white_max:
+                    image_gray[each_height, each_weight] = 255  # 判定为最白区域的，直接改为白色
                 else:
-                    image[each_height, each_weight] = 0  # 其他区域直接改为黑色
+                    image_gray[each_height, each_weight] = 0  # 其他区域直接改为黑色
             else:
-                if image[each_height, each_weight] >= white_value:
-                    image[each_height, each_weight] = 255  # 判定为最白区域的，直接改为白色
+                if image_gray[each_height, each_weight] >= white_value_max:
+                    image_gray[each_height, each_weight] = 255  # 判定为最白区域的，直接改为白色
                 else:
-                    image[each_height, each_weight] = 0  # 其他区域直接改为黑色
+                    image_gray[each_height, each_weight] = 0  # 其他区域直接改为黑色
 
-    cv2.imwrite(proc_file_dir, image)
+    cv2.imwrite(proc_file_dir, image_gray)
     return proc_file_dir
 
 
